
# Slot: boolean_slot


A grouping of slots that expression a boolean operator over a list of operands

URI: [linkml:boolean_slot](https://w3id.org/linkml/boolean_slot)


## Domain and Range

None &#8594;  <sub>0..\*</sub> expression

## Parents


## Children

 *  all_of
 *  any_of
 *  exactly_one_of
 *  none_of

## Used by

